@@ -1,7 +1,8 @@
 # SciViews specific R Commander code
 
-# last modified 24 October 2004 by Ph. Grosjean
+# last modified 19 April 2005 by Ph. Grosjean
 #  small fix to call to list.files() by J. Fox 17 Jan 05
+#  modifications 16 Mar 05 by J. Fox
 
 is.SciViews <- function() {
     # SciViews defines the option "SciViews.version".
@@ -25,70 +26,76 @@ tkfocus <- function(...){
 svCommander <- function(){
     # The SciViews specific Commander() function
     if (is.SciViews()) {
-        ### TO DO: automatically generate the menu from "Rcmdr-menus.txt"
+        # TO DO: automatically generate the menu from "Rcmdr-menus.txt"
         # Display the R commander menu
         #...
         setOption <- function(option, default, global=TRUE) {
             opt <- if (is.null(current[[option]])) default else current[[option]]
-            if (global) assign(paste(".", option, sep=""), opt, envir=.GlobalEnv)
+            if (global) putRcmdr(option, opt)
             else opt
             }
         etc <- file.path(.path.package(package="Rcmdr")[1], "etc")
         # Do NOT sink error messages!
         #assign(".messages.connection", textConnection(".messages", open = "w"), envir=.GlobalEnv)
         #sink(.messages.connection, type="message")
-        assign(".length.messages", 0, envir=.GlobalEnv)
-        assign(".activeDataSet", NULL, envir=.GlobalEnv)
-        assign(".activeModel", NULL, envir=.GlobalEnv)
-        assign(".logFileName", NULL, envir=.GlobalEnv)
-        assign(".outputFileName", NULL, envir=.GlobalEnv)
-        assign(".modelNumber", 0, envir=.GlobalEnv)
-        assign(".rgl", FALSE, envir=.GlobalEnv)
+		putRcmdr("length.messages", 0)
+        putRcmdr(".activeDataSet", NULL)
+        putRcmdr(".activeModel", NULL)
+        putRcmdr("logFileName", NULL)
+        putRcmdr("outputFileName", NULL)
+        putRcmdr("saveFileName", NULL)
+        putRcmdr("modelNumber", 0)
+        putRcmdr("rgl", FALSE)
         current <- options("Rcmdr")[[1]]
-        setOption("log.font.size", 10)
-        assign(".logFont", tkfont.create(family="courier", size=.log.font.size), envir=.GlobalEnv)
-        assign(".operatorFont", tkfont.create(family="courier", size=.log.font.size),
-            envir=.GlobalEnv)
-        scale.factor <- current$scale.factor
+        putRcmdr("log.font.size", 10)
+		putRcmdr("logFont", tkfont.create(family="courier", size=getRcmdr("log.font.size")))
+    	putRcmdr("operatorFont", tkfont.create(family="courier", size=getRcmdr("log.font.size")))
+		scale.factor <- current$scale.factor
         if (!is.null(scale.factor)) .Tcl(paste("tk scaling ", scale.factor, sep=""))
-        setOption("contrasts", c("contr.Treatment", "contr.poly"))
+        if (packageLoaded("car")) setOption("contrasts", c("contr.Treatment", "contr.poly"))
+        	else setOption("contrasts", c("contr.treatment", "contr.poly"))
         setOption("log.commands", TRUE)
-        assign(".logCommands", if (.log.commands) tclVar("1") else tclVar("0"), envir=.GlobalEnv)
+        assign("logCommands", if (log.commands) tclVar("1") else tclVar("0"))
         setOption("console.output", TRUE) # Must be set to TRUE for SciViews app!
-        log.height <- as.character(setOption("log.height", if (!.log.commands) 0 else 10, global=FALSE))
+        log.height <- as.character(setOption("log.height", if (!log.commands) 0 else 10, global=FALSE))
         log.width <- as.character(setOption("log.width", 80, global=FALSE))
-        output.height <- as.character(setOption("output.height",
-            if (.console.output) 0
-            else if ((as.numeric(log.height) != 0) || (!.log.commands)) 2*as.numeric(log.height)
-            else 20, global=FALSE))
+    	output.height <- as.character(setOption("output.height",
+        	if (getRcmdr("console.output")) 0
+        	else if ((as.numeric(log.height) != 0) || (!getRcmdr("log.commands"))) 2*as.numeric(log.height)
+        	else 20, global=FALSE))
         setOption("output.height", output.height)
-        assign(".saveOptions", options(warn=1, contrasts=.contrasts, width=as.numeric(log.width),
-            na.action="na.exclude", graphics.record=TRUE), envir=.GlobalEnv)
+        putRcmdr("saveOptions", options(warn=1, contrasts=getRcmdr("contrasts"), width=as.numeric(log.width),
+            na.action="na.exclude", graphics.record=TRUE))
         setOption("double.click", FALSE)
         setOption("sort.names", TRUE)
         setOption("grab.focus", TRUE)
-        setOption("attach.data.set", TRUE)
+        setOption("attach.data.set", FALSE)
         setOption("log.text.color", "black")
         setOption("command.text.color", "red")
         setOption("output.text.color", "darkblue")
         setOption("multiple.select.mode", "extended")
+        setOption("report.X11.warnings", FALSE) # to address problem in Linux
+    	setOption("showData.threshold", 100)
+    	setOption("retain.messages", FALSE)
         if (.Platform$OS.type != "windows") {
-            assign(".oldPager", options(pager=RcmdrPager), envir=.GlobalEnv)
-            default.font.size <- as.character(setOption("default.font.size", 10, global=FALSE))
-            default.font <- setOption("default.font",
-                paste("*helvetica-medium-r-normal-*-", default.font.size, "*", sep=""), global=FALSE)
-            .Tcl(paste("option add *font ", default.font, sep=""))
-            }
-        placement <- setOption("placement", "-40+40", global=FALSE)
+        	putRcmdr("oldPager", options(pager=RcmdrPager))
+        	default.font.size <- as.character(setOption("default.font.size", 10, global=FALSE))
+        	default.font <- setOption("default.font",
+            	paste("*helvetica-medium-r-normal-*-", default.font.size, "*", sep=""), global=FALSE)
+        	.Tcl(paste("option add *font ", default.font, sep=""))
+        	}
+        putRcmdr("commanderWindow", NULL)
+        .commander <- NULL
+		placement <- setOption("placement", "-40+20", global=FALSE)
 #        source.files <- list.files(etc, pattern="\\.R$")  # duplicate line commented out by J. Fox
-        .commander.done <<- tclVar("0") # to address problem in Debian Linux
+#        .commander.done <<- tclVar("0")
         source.files <- list.files(etc, pattern="\\.[Rr]$")
         for (file in source.files) {
              source(file.path(etc, file))
              cat(paste("Sourced:", file, "\n"))
              }
         Menus <- read.table(file.path(etc, "Rcmdr-menus.txt"), as.is=TRUE)
-        ### TO DO: we need another treatment for this!
+        # TO DO: we need another treatment for this!
         #for (m in 1:nrow(Menus)){
         #    if (Menus[m, 1] == "menu") assign(Menus[m, 2], tkmenu(eval(parse(text=Menus[m, 3])), tearoff=FALSE))
         #    else if (Menus[m, 1] == "item") {
@@ -100,50 +107,74 @@ svCommander <- function(){
         #         }
         #    else stop(paste("menu defintion error:", Menus[m, ], collapse=" "))
         #    }
-        exceptions <- scan(file.path(etc, "log-exceptions.txt"), what="", quiet=TRUE, comment.char="#")
-        assign(".dataSetName", tclVar("<No active dataset>"), envir=.GlobalEnv)
-        assign(".modelName", tclVar("<No active model>"), envir=.GlobalEnv)
-        show.edit.button <- options("Rcmdr")[[1]]$show.edit.button
+        putRcmdr("Menus", list())
+		exceptions <- scan(file.path(etc, "log-exceptions.txt"), what="", quiet=TRUE, comment.char="#")
+        putRcmdr("modelClasses", scan(file.path(etc, "model-classes.txt"), what="", quiet=TRUE, comment.char="#"))
+		putRcmdr("dataSetName", tclVar("<No active dataset>"))
+		putRcmdr("dataSetLabel", NULL)
+        putRcmdr("logWindow", NULL)
+        putRcmdr("outputWindow", NULL)
+		putRcmdr("messagesWindow", NULL)
+		putRcmdr("modelName", tclVar("<No active model>"))
+        putRcmdr("modelLabel", NULL)
+		show.edit.button <- options("Rcmdr")[[1]]$show.edit.button
         show.edit.button <- if (is.null(show.edit.button)) TRUE else show.edit.button
         }
     }
 
 svlogger <- function(command){
-    # the SciViews specific logger() function
-    if (is.SciViews()) {
-        # Behaviour is different if it is a TclTk communicating client,
-        # or a plug
-        if (is.SciViews.TclTk()) { # TclTk SciViews client
-            # getTemp from SciViews[svMisc] is redefined here to avoid a Depends: svMisc!
-            getTemp <- function(x, default = NULL, mode="any") {
-                if  (exists(x, envir = TempEnv(), mode = mode, inherits = FALSE)) {
-                    return(get(x, envir = TempEnv(), mode = mode, inherits = FALSE))
-                } else { # Variable not found, return the default value
-                    return(default)
-                }
-            }
-            if (tclvalue(.logCommands) == "1") {
-                CmdFun <- getTemp(".guiCmd", mode = "function")
-                if (!is.null(CmdFun)) CmdFun(paste("Log\n", command))
-            }
-            lines <- strsplit(command, "\n")[[1]]
-            for (line in lines) cat(paste("\n Rcmdr ", line, "\n"))
-            command
-        } else {    # plug SciViews client
-            lines <- strsplit(command, "\n")[[1]]
-            for (line in lines) {
-                cat(paste("History", line, "\n ", line, "    #[R-cmdr]\n", sep=""))
-                if (tclvalue(.logCommands) == "1") cat(paste("Script", command, "\n", sep=""))
-                }
-            command
-            }
-        }
-    }
+     # the SciViews specific logger() function
+     if (is.SciViews()) {
+         # Behaviour is different if it is a TclTk communicating client,
+         # or a plug
+         if (is.SciViews.TclTk()) { # TclTk SciViews client
+             getTemp <- function(x, default = NULL, mode="any") {
+                 if  (exists(x, envir = TempEnv(), mode = mode,
+					inherits = FALSE)) {
+                     return(get(x, envir = TempEnv(), mode = mode,
+						inherits = FALSE))
+                 } else { # Variable not found, return the default value
+                     return(default)
+                 }
+             }
+             if (getRcmdr("log.commands")) {
+                 CmdFun <- getTemp(".guiCmd", mode = "function")
+                 if (!is.null(CmdFun)) CmdFun(paste("<<<<Log\n", command))
+             }
+             lines <- strsplit(command, "\n")[[1]]
+             for (line in lines) cat(paste("\n>>>> Rcmdr >>>>", line, "\n"))
+             command
+         } else {    # plug SciViews client
+             lines <- strsplit(command, "\n")[[1]]
+             for (line in lines) {
+                 cat(paste("<<<<History", line, "<<<<\n>>>> ", line,
+					"    #[R-cmdr]\n", sep=""))
+                 if (getRcmdr("log.commands")) cat(paste("<<<<Script",
+					command, "\n<<<<", sep=""))
+                 }
+             command
+             }
+         }
+     }
+    
+svMessage <- function(message, type = c("note", "error", "warning")) {
+	# the SciViews specific Message function
+	type <- match.arg(type)
+    type <- type[1]
+	if (type == "note") return()    # Currently we display nothing if it is a note!
+	if (type != "note") tkbell()
+    prefix <- switch(type, error="ERROR", warning="WARNING", note="NOTE", "RCMDR")
+    if (missing(message)) return()
+    message <- paste(prefix, ": ", message, sep="")
+    lines <- strsplit(message, "\n")[[1]]
+    for (line in lines) cat(line, "\n")
+	}
 
 activeDataSetEdit <- function() {
     # This is SciViews equivalent to onEdit function of Commander()
     if (activeDataSet() == FALSE)
         return()
+    .activeDataSet <- ActiveDataSet()
     command <- paste("fix(", .activeDataSet, ")", sep="")
     justDoIt(command)
     svlogger(command)
@@ -156,7 +187,7 @@ activeDataSetView <- function() {
     if (activeDataSet() == FALSE)
         return()
     view.height <- 30 #max(as.numeric(output.height) + as.numeric(log.height), 10)
-    command <- paste("showData(", .activeDataSet, ", placement='-20+200', font=.logFont, maxwidth=", 
+    command <- paste("showData(", ActiveDataSet(), ", placement='-20+200', font=getRcmdr('logFont'), maxwidth=",
     80, ", maxheight=", view.height, ")", sep="")
     justDoIt(command)
     invisible(svlogger(command))
@@ -166,10 +197,8 @@ optionLogCommand <- function() {
     # Change log option in SciViews
     response <- tclvalue(tkmessageBox(message="Log R-cmdr commands in a script?",
         icon="question", type="yesno", default="yes"))
-    val <- if (response == "yes") tclVar("1") else tclVar("0")
-    assign(".logCommands", val, envir=.GlobalEnv)
     val <- if (response == "yes") TRUE else FALSE
-    assign(".log.commands", val, envir=.GlobalEnv)
+    putRcmdr("log.commands", val)
     Opts <- options("Rcmdr")[[1]]
     Opts$log.commands <- val
     options(Rcmdr=Opts)
@@ -181,7 +210,7 @@ optionAttachDataSet <- function() {
     response <- tclvalue(tkmessageBox(message="Attach active data set?",
         icon="question", type="yesno", default="yes"))
     val <- if (response == "yes") TRUE else FALSE
-    assign(".attach.data.set", val, envir=.GlobalEnv)
+    putRcmdr("attach.data.set", val)
     Opts <- options("Rcmdr")[[1]]
     Opts$attach.data.set <- val
     options(Rcmdr=Opts)
@@ -193,7 +222,7 @@ optionSortVariables <- function() {
     response <- tclvalue(tkmessageBox(message="Sort variable names alphabetically?",
         icon="question", type="yesno", default="yes"))
     val <- if (response == "yes") TRUE else FALSE
-    assign(".sort.names", val, envir=.GlobalEnv)
+    putRcmdr("sort.names", val)
     Opts <- options("Rcmdr")[[1]]
     Opts$sort.names <- val
     options(Rcmdr=Opts)
@@ -202,13 +231,13 @@ optionSortVariables <- function() {
 
 refreshStatus <- function() {
     # Refresh dataset and model indication in the status bar of SciViews Client
-    DataSet <- get(".activeDataSet", pos = .GlobalEnv)
+    DataSet <- ActiveDataSet()
     if (is.null(DataSet) || length(DataSet) == 0) DataSet <- "<no data>"
-    Model <- get(".activeModel", pos = .GlobalEnv)
+    Model <- ActiveModel()
     if (is.null(Model) || length(Model) == 0) Model <- "<no model>"
-    if (get(".log.commands", pos = .GlobalEnv)) Opts <- " [log]" else Opts <- " "
-    if (get(".attach.data.set", pos = .GlobalEnv)) Opts <- paste(Opts, "[attach]", sep="")
-    if (get(".sort.names", pos = .GlobalEnv)) Opts <- paste(Opts, "[sort]", sep="")
+    if (getRcmdr("log.commands")) Opts <- " [log]" else Opts <- " "
+    if (getRcmdr("attach.data.set")) Opts <- paste(Opts, "[attach]", sep="")
+    if (getRcmdr("sort.names")) Opts <- paste(Opts, "[sort]", sep="")
     # If it is a "SciViews TclTk GUI" client, use it...
     if (is.SciViews.TclTk()) {
         cat(paste("Data: ", DataSet, ", Model: ", Model, Opts, sep=""), file = file.path(tempdir(), "svStatus.txt"))
